@@ -1,9 +1,8 @@
 import asyncio
 from collections.abc import AsyncIterator
-from typing import Literal
+from typing import Literal, cast
 
 import orjson
-from langgraph.checkpoint.base.id import uuid6
 from starlette.exceptions import HTTPException
 from starlette.responses import Response, StreamingResponse
 
@@ -11,9 +10,17 @@ from langgraph_api import config
 from langgraph_api.asyncio import ValueEvent, aclosing
 from langgraph_api.models.run import create_valid_run
 from langgraph_api.route import ApiRequest, ApiResponse, ApiRoute
+from langgraph_api.schema import CRON_FIELDS, RUN_FIELDS
 from langgraph_api.sse import EventSourceResponse
-from langgraph_api.utils import fetchone, get_pagination_headers, validate_uuid
+from langgraph_api.utils import (
+    fetchone,
+    get_pagination_headers,
+    uuid7,
+    validate_select_columns,
+    validate_uuid,
+)
 from langgraph_api.validation import (
+    CronCountRequest,
     CronCreate,
     CronSearch,
     RunBatchCreate,
@@ -92,7 +99,7 @@ async def stream_run(
     thread_id = request.path_params["thread_id"]
     payload = await request.json(RunCreateStateful)
     on_disconnect = payload.get("on_disconnect", "continue")
-    run_id = uuid6()
+    run_id = uuid7()
     sub = asyncio.create_task(Runs.Stream.subscribe(run_id))
 
     try:
@@ -132,7 +139,7 @@ async def stream_run_stateless(
     """Create a stateless run."""
     payload = await request.json(RunCreateStateless)
     on_disconnect = payload.get("on_disconnect", "continue")
-    run_id = uuid6()
+    run_id = uuid7()
     sub = asyncio.create_task(Runs.Stream.subscribe(run_id))
 
     try:
@@ -173,7 +180,7 @@ async def wait_run(request: ApiRequest):
     thread_id = request.path_params["thread_id"]
     payload = await request.json(RunCreateStateful)
     on_disconnect = payload.get("on_disconnect", "continue")
-    run_id = uuid6()
+    run_id = uuid7()
     sub = asyncio.create_task(Runs.Stream.subscribe(run_id))
 
     try:
@@ -205,9 +212,11 @@ async def wait_run(request: ApiRequest):
             )
         ) as stream:
             async for mode, chunk, _ in stream:
-                if mode == b"values":
-                    vchunk = chunk
-                elif mode == b"updates" and b"__interrupt__" in chunk:
+                if (
+                    mode == b"values"
+                    or mode == b"updates"
+                    and b"__interrupt__" in chunk
+                ):
                     vchunk = chunk
                 elif mode == b"error":
                     vchunk = orjson.dumps({"__error__": orjson.Fragment(chunk)})
@@ -255,7 +264,7 @@ async def wait_run_stateless(request: ApiRequest):
     """Create a stateless run, wait for the output."""
     payload = await request.json(RunCreateStateless)
     on_disconnect = payload.get("on_disconnect", "continue")
-    run_id = uuid6()
+    run_id = uuid7()
     sub = asyncio.create_task(Runs.Stream.subscribe(run_id))
 
     try:
@@ -288,9 +297,11 @@ async def wait_run_stateless(request: ApiRequest):
             )
         ) as stream:
             async for mode, chunk, _ in stream:
-                if mode == b"values":
-                    vchunk = chunk
-                elif mode == b"updates" and b"__interrupt__" in chunk:
+                if (
+                    mode == b"values"
+                    or mode == b"updates"
+                    and b"__interrupt__" in chunk
+                ):
                     vchunk = chunk
                 elif mode == b"error":
                     vchunk = orjson.dumps({"__error__": orjson.Fragment(chunk)})
@@ -338,6 +349,9 @@ async def list_runs(
     limit = int(request.query_params.get("limit", 10))
     offset = int(request.query_params.get("offset", 0))
     status = request.query_params.get("status")
+    select = validate_select_columns(
+        request.query_params.getlist("select") or None, RUN_FIELDS
+    )
 
     async with connect() as conn, conn.pipeline():
         thread, runs = await asyncio.gather(
@@ -348,6 +362,7 @@ async def list_runs(
                 limit=limit,
                 offset=offset,
                 status=status,
+                select=select,
             ),
         )
     await fetchone(thread)
@@ -425,7 +440,10 @@ async def cancel_run(
     wait_str = request.query_params.get("wait", "false")
     wait = wait_str.lower() in {"true", "yes", "1"}
     action_str = request.query_params.get("action", "interrupt")
-    action = action_str if action_str in {"interrupt", "rollback"} else "interrupt"
+    action = cast(
+        Literal["interrupt", "rollback"],
+        action_str if action_str in {"interrupt", "rollback"} else "interrupt",
+    )
 
     async with connect() as conn:
         await Runs.cancel(
@@ -471,8 +489,9 @@ async def cancel_runs(
         for rid in run_ids:
             validate_uuid(rid, "Invalid run ID: must be a UUID")
     action_str = request.query_params.get("action", "interrupt")
-    action: Literal["interrupt", "rollback"] = (
-        action_str if action_str in ("interrupt", "rollback") else "interrupt"
+    action = cast(
+        Literal["interrupt", "rollback"],
+        action_str if action_str in ("interrupt", "rollback") else "interrupt",
     )
 
     async with connect() as conn:
@@ -557,6 +576,7 @@ async def delete_cron(request: ApiRequest):
 async def search_crons(request: ApiRequest):
     """List all cron jobs for an assistant"""
     payload = await request.json(CronSearch)
+    select = validate_select_columns(payload.get("select") or None, CRON_FIELDS)
     if assistant_id := payload.get("assistant_id"):
         validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
     if thread_id := payload.get("thread_id"):
@@ -572,6 +592,7 @@ async def search_crons(request: ApiRequest):
             offset=offset,
             sort_by=payload.get("sort_by"),
             sort_order=payload.get("sort_order"),
+            select=select,
         )
     crons, response_headers = await get_pagination_headers(
         crons_iter, next_offset, offset
@@ -579,6 +600,24 @@ async def search_crons(request: ApiRequest):
     return ApiResponse(crons, headers=response_headers)
 
 
+@retry_db
+async def count_crons(request: ApiRequest):
+    """Count cron jobs."""
+    payload = await request.json(CronCountRequest)
+    if assistant_id := payload.get("assistant_id"):
+        validate_uuid(assistant_id, "Invalid assistant ID: must be a UUID")
+    if thread_id := payload.get("thread_id"):
+        validate_uuid(thread_id, "Invalid thread ID: must be a UUID")
+
+    async with connect() as conn:
+        count = await Crons.count(
+            conn,
+            assistant_id=assistant_id,
+            thread_id=thread_id,
+        )
+    return ApiResponse(count)
+
+
 runs_routes = [
     ApiRoute("/runs/stream", stream_run_stateless, methods=["POST"]),
     ApiRoute("/runs/wait", wait_run_stateless, methods=["POST"]),
@@ -595,6 +634,11 @@ runs_routes = [
         if config.FF_CRONS_ENABLED and plus_features_enabled()
         else None
     ),
+    (
+        ApiRoute("/runs/crons/count", count_crons, methods=["POST"])
+        if config.FF_CRONS_ENABLED and plus_features_enabled()
+        else None
+    ),
     ApiRoute("/threads/{thread_id}/runs/{run_id}/join", join_run, methods=["GET"]),
     ApiRoute(
         "/threads/{thread_id}/runs/{run_id}/stream",
