@@ -4,4 +4,5 @@ from langgraph.version import __version__
 LANGGRAPH_PY_MINOR = tuple(map(int, __version__.split(".")[:2]))
 
 OMIT_PENDING_SENDS = LANGGRAPH_PY_MINOR >= (0, 5)
-USE_RUNTIME_API = LANGGRAPH_PY_MINOR >= (0, 6)
+USE_RUNTIME_CONTEXT_API = LANGGRAPH_PY_MINOR >= (0, 6)
+USE_NEW_INTERRUPTS = LANGGRAPH_PY_MINOR >= (0, 6)
