@@ -1,4 +1,5 @@
 import asyncio
+import contextlib
 import json
 import logging
 import os
@@ -7,7 +8,6 @@ import shutil
 import ssl
 from collections import deque
 from collections.abc import AsyncIterator, Callable
-from contextlib import AbstractContextManager
 from typing import Any, Literal, Self, cast
 
 import certifi
@@ -57,11 +57,10 @@ GRAPH_PORT = 5556
 GRAPH_HTTP_PORT = 5557
 SSL = ssl.create_default_context(cafile=certifi.where())
 
-if port := int(os.getenv("PORT", "8080")):
-    if port in (GRAPH_PORT, REMOTE_PORT):
-        raise ValueError(
-            f"PORT={port} is a reserved port for the JS worker. Please choose a different port."
-        )
+if (port := int(os.getenv("PORT", "8080"))) and port in (GRAPH_PORT, REMOTE_PORT):
+    raise ValueError(
+        f"PORT={port} is a reserved port for the JS worker. Please choose a different port."
+    )
 
 _client = httpx.AsyncClient(
     base_url=f"http://localhost:{GRAPH_PORT}",
@@ -106,6 +105,10 @@ async def _client_stream(method: str, data: dict[str, Any]):
                 yield sse.data
 
 
+class NoopModel(BaseModel):
+    pass
+
+
 async def _client_invoke(method: str, data: dict[str, Any]):
     graph_id = data.get("graph_id")
     res = await _client.post(
@@ -177,13 +180,10 @@ class RemotePregel(BaseRemotePregel):
         nodes: list[Any] = response.pop("nodes")
         edges: list[Any] = response.pop("edges")
 
-        class NoopModel(BaseModel):
-            pass
-
         return DrawableGraph(
             {
                 data["id"]: Node(
-                    data["id"], data["id"], NoopModel(), data.get("metadata")
+                    data["id"], data["id"], NoopModel, data.get("metadata")
                 )
                 for data in nodes
             },
@@ -244,9 +244,9 @@ class RemotePregel(BaseRemotePregel):
                 )
             return tuple(result)
 
-        return StateSnapshot(
+        return StateSnapshot(  # type: ignore[missing-argument]
             item.get("values"),
-            item.get("next"),
+            cast(tuple, item.get("next", ())),
             item.get("config"),
             item.get("metadata"),
             item.get("createdAt"),
@@ -352,7 +352,7 @@ class RemotePregel(BaseRemotePregel):
         return result["nodesExecuted"]
 
 
-async def run_js_process(paths_str: str, watch: bool = False):
+async def run_js_process(paths_str: str | None, watch: bool = False):
     # check if tsx is available
     tsx_path = shutil.which("tsx")
     if tsx_path is None:
@@ -360,7 +360,7 @@ async def run_js_process(paths_str: str, watch: bool = False):
             "tsx not found in PATH. Please upgrade to latest LangGraph CLI to support running JS graphs."
         )
     attempt = 0
-    while not asyncio.current_task().cancelled():
+    while (current_task := asyncio.current_task()) and not current_task.cancelled():
         client_file = os.path.join(os.path.dirname(__file__), "client.mts")
         client_preload_file = os.path.join(
             os.path.dirname(__file__), "src", "preload.mjs"
@@ -378,6 +378,7 @@ async def run_js_process(paths_str: str, watch: bool = False):
             if False
             else ("tsx", "--import", client_preload_file, client_file)
         )
+        process = None
         try:
             process = await asyncio.create_subprocess_exec(
                 *args,
@@ -394,11 +395,10 @@ async def run_js_process(paths_str: str, watch: bool = False):
             raise Exception(f"JS process exited with code {code}")
         except asyncio.CancelledError:
             logger.info("Terminating JS graphs process")
-            try:
-                process.terminate()
-                await process.wait()
-            except (UnboundLocalError, ProcessLookupError):
-                pass
+            if process is not None:
+                with contextlib.suppress(ProcessLookupError):
+                    process.terminate()
+                    await process.wait()
             raise
         except Exception:
             if attempt >= 3:
@@ -408,7 +408,9 @@ async def run_js_process(paths_str: str, watch: bool = False):
                 attempt += 1
 
 
-async def run_js_http_process(paths_str: str, http_config: dict, watch: bool = False):
+async def run_js_http_process(
+    paths_str: str | None, http_config: dict, watch: bool = False
+):
     # check if tsx is available
     tsx_path = shutil.which("tsx")
     if tsx_path is None:
@@ -417,10 +419,11 @@ async def run_js_http_process(paths_str: str, http_config: dict, watch: bool = F
         )
 
     attempt = 0
-    while not asyncio.current_task().cancelled():
+    while (current_task := asyncio.current_task()) and not current_task.cancelled():
         client_file = os.path.join(os.path.dirname(__file__), "client.http.mts")
         args = ("tsx", "watch", client_file) if watch else ("tsx", client_file)
         pid = None
+        process = None
         try:
             process = await asyncio.create_subprocess_exec(
                 *args,
@@ -442,11 +445,10 @@ async def run_js_http_process(paths_str: str, http_config: dict, watch: bool = F
 
         except asyncio.CancelledError:
             logger.info("Shutting down JS HTTP process [%d]", pid or -1)
-            try:
-                process.terminate()
-                await process.wait()
-            except (UnboundLocalError, ProcessLookupError):
-                pass
+            if process is not None:
+                with contextlib.suppress(ProcessLookupError):
+                    process.terminate()
+                    await process.wait()
             raise
         except Exception:
             if attempt >= 3:
@@ -763,7 +765,7 @@ async def run_remote_checkpointer():
     await server.serve()
 
 
-class DisableHttpxLoggingContextManager(AbstractContextManager):
+class DisableHttpxLoggingContextManager(contextlib.AbstractContextManager):
     """
     Disable HTTP/1.1 200 OK logs spamming stdout.
     """
@@ -795,7 +797,9 @@ async def wait_until_js_ready():
             ) as checkpointer_client,
         ):
             attempt = 0
-            while not asyncio.current_task().cancelled():
+            while (
+                current_task := asyncio.current_task()
+            ) and not current_task.cancelled():
                 try:
                     res = await graph_client.get("/ok")
                     res.raise_for_status()
@@ -886,11 +890,10 @@ class CustomJsAuthBackend(AuthenticationBackend):
         cache_key = None
         if self.cache_keys:
             cache_key = tuple((k, headers[k]) for k in self.cache_keys if k in headers)
-            if cache_key:
-                if self.ttl_cache is not None:
-                    cached = self.ttl_cache.get(cache_key)
-                    if cached:
-                        return cached
+            if cache_key and self.ttl_cache is not None:
+                cached = self.ttl_cache.get(cache_key)
+                if cached:
+                    return cached
 
         res = await _client.post("/auth/authenticate", headers=headers)
         data = res.json()
@@ -909,7 +912,7 @@ class CustomJsAuthBackend(AuthenticationBackend):
 
 
 async def handle_js_auth_event(
-    ctx: Auth.types.AuthContext | None,
+    ctx: Auth.types.AuthContext,
     value: dict,
 ) -> Auth.types.FilterType | None:
     if hasattr(ctx.user, "dict") and callable(ctx.user.dict):
@@ -956,11 +959,14 @@ async def handle_js_auth_event(
     # mutate metadata in value if applicable
     # we need to preserve the identity of the object, so cannot create a new
     # dictionary, otherwise the changes will not persist
-    if isinstance(value, dict) and (updated_value := response.get("value")):
-        if isinstance(value.get("metadata"), dict) and (
-            metadata := updated_value.get("metadata")
-        ):
-            value["metadata"].update(metadata)
+    metadata = None
+    if (
+        isinstance(value, dict)
+        and (updated_value := response.get("value"))
+        and isinstance(value.get("metadata"), dict)
+        and (metadata := updated_value.get("metadata"))
+    ):
+        value["metadata"].update(metadata)
 
     return filters
 
