@@ -61,9 +61,15 @@ BEACON_ENDPOINT = "https://api.smith.langchain.com/v1/metadata/submit"
 # LangChain auth endpoint for API key submissions
 LANGCHAIN_METADATA_ENDPOINT = None
 if LANGSMITH_AUTH_ENDPOINT:
-    LANGCHAIN_METADATA_ENDPOINT = (
-        LANGSMITH_AUTH_ENDPOINT.rstrip("/") + "/v1/metadata/submit"
-    )
+    if "/api/v1" in LANGSMITH_AUTH_ENDPOINT:
+        # If the endpoint already has /api/v1 (for self-hosted control plane deployments), we assume it's the correct format
+        LANGCHAIN_METADATA_ENDPOINT = (
+            LANGSMITH_AUTH_ENDPOINT.rstrip("/") + "/metadata/submit"
+        )
+    else:
+        LANGCHAIN_METADATA_ENDPOINT = (
+            LANGSMITH_AUTH_ENDPOINT.rstrip("/") + "/v1/metadata/submit"
+        )
 
 
 def incr_runs(*, incr: int = 1) -> None:
