@@ -1,4 +1,5 @@
 import asyncio
+import base64
 import re
 import uuid
 from base64 import b64encode
@@ -16,7 +17,7 @@ from ipaddress import (
 )
 from pathlib import Path
 from re import Pattern
-from typing import Any, NamedTuple
+from typing import Any, NamedTuple, cast
 from zoneinfo import ZoneInfo
 
 import cloudpickle
@@ -46,10 +47,14 @@ def decimal_encoder(dec_value: Decimal) -> int | float:
     >>> decimal_encoder(Decimal("1"))
     1
     """
-    if dec_value.as_tuple().exponent >= 0:
-        return int(dec_value)
-    else:
+    if (
+        # maps to float('nan') / float('inf') / float('-inf')
+        not dec_value.is_finite()
+        # or regular float
+        or cast(int, dec_value.as_tuple().exponent) < 0
+    ):
         return float(dec_value)
+    return int(dec_value)
 
 
 def default(obj):
@@ -79,11 +84,10 @@ def default(obj):
         return obj.total_seconds()
     elif isinstance(obj, Decimal):
         return decimal_encoder(obj)
-    elif isinstance(obj, uuid.UUID):
-        return str(obj)
     elif isinstance(  # noqa: UP038
         obj,
         (
+            uuid.UUID,
             IPv4Address,
             IPv4Interface,
             IPv4Network,
@@ -142,7 +146,7 @@ def json_loads(content: bytes | Fragment | dict) -> Any:
         content = content.buf
     if isinstance(content, dict):
         return content
-    return orjson.loads(content)
+    return orjson.loads(cast(bytes, content))
 
 
 async def ajson_loads(content: bytes | Fragment) -> Any:
@@ -170,3 +174,25 @@ class Serializer(JsonPlusSerializer):
                 )
                 return None
         return super().loads_typed(data)
+
+
+mpack_keys = {"method", "value"}
+SERIALIZER = Serializer()
+
+
+# TODO: Make more performant (by removing)
+async def reserialize_message(message: bytes) -> bytes:
+    # Stream messages from golang runtime are a byte dict of StreamChunks.
+    loaded = await ajson_loads(message)
+    converted = {}
+    for k, v in loaded.items():
+        if isinstance(v, dict) and v.keys() == mpack_keys:
+            if v["method"] == "missing":
+                converted[k] = v["value"]  # oops
+            else:
+                converted[k] = SERIALIZER.loads_typed(
+                    (v["method"], base64.b64decode(v["value"]))
+                )
+        else:
+            converted[k] = v
+    return json_dumpb(converted)
