@@ -2,7 +2,7 @@ import uuid
 from collections.abc import AsyncIterator, Callable
 from contextlib import AsyncExitStack, aclosing, asynccontextmanager
 from functools import lru_cache
-from typing import Any, cast
+from typing import Any, Literal, cast
 
 import langgraph.version
 import langsmith
@@ -423,7 +423,7 @@ async def consume(
     stream: AnyStream,
     run_id: str | uuid.UUID,
     resumable: bool = False,
-    stream_modes: set[StreamMode] | None = None,
+    stream_modes: set[StreamMode | Literal["metadata"]] | None = None,
 ) -> None:
     stream_modes = stream_modes or set()
     if "messages-tuple" in stream_modes:
